## ----fig1----------------------------------------------------------------
library(pcrmeta)

plot_surrogates(TRUE, TRUE)
plot_surrogates(TRUE, FALSE)
plot_surrogates(FALSE, TRUE)

## ----table, results = "asis", echo = FALSE-------------------------------
library(knitr)

kable(trials10)

## ----table2, results = "asis", echo = FALSE------------------------------
kable(trials13)

## ----like----------------------------------------------------------------
like.hood.model4

## ----pred----------------------------------------------------------------
predict_klmfit

## ----cortefs, results = 'asis'-------------------------------------------
ten.dfs <- with(trials10, fit_model4(log(HR.DFS), log(OR.PCR), DFS.SE, PCR.SE))
kable(ten.dfs$summary)

## ----cortpredefs, results = 'asis'---------------------------------------
library(magrittr)
library(tidyr)

params <- data.frame(p1 = rep(1:4/10, 3), 
                     p0 = rep(c(.1, .1, .1, .2), 3), 
                     n = sort(rep(c(100, 300, 1000), 4)))

params$CI <- sapply(1:nrow(params), function(i){
  
  with(params[i, ], fill_table(p1, p0, n, ten.dfs)$a1)
  
})

params %>% 
  spread(n, CI) %>% kable

## ----cortfig, echo = FALSE-----------------------------------------------
library(ggplot2)
citr <- function(or, se, lower = TRUE){
  
  exp(log(or) + ifelse(lower, -1, 1) * se)
  
}

xlim = c(0.38, 7.3)
ylim = c(0.08, 2.18)

baseEFS <- ggplot(trials10, aes(x = OR.PCR, y = HR.DFS, 
                 ymin = citr(HR.DFS, DFS.SE), ymax = citr(HR.DFS, DFS.SE, FALSE), 
                 xmin = citr(OR.PCR, PCR.SE), xmax = citr(OR.PCR, PCR.SE, FALSE), 
                 size = Patients)) + guides(size = FALSE) + 
  geom_point(shape = 15) + 
  scale_size_area(max_size = 3) + 
  geom_errorbar(width = 0.05, alpha = 1, size = .1, aes(size = NULL, color = NULL)) +
  geom_errorbarh(height = 0.05, alpha = 1, size = .1, aes(size = NULL, color = NULL)) +
  scale_y_continuous("Hazard ratio for EFS", trans = "log", lim = ylim, breaks = c(.4, .6, .8, 1, 1.2, 1.4)) + 
  scale_x_continuous("Odds ratio for pCR", trans = "log", lim = xlim,  breaks = c(.1, 1, 2, 3, 5, 6)) + 
  geom_vline(xintercept = 1, size = .5, linetype = 3) + geom_hline(yintercept = 1, size = 0.5, linetype = 3) + 
  theme_bw() + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())

baseEFS + ggtitle("EFS, 10 Trials")

## ----berefs, results = 'asis'--------------------------------------------
all.dfs <- with(rbind(trials10, trials13), 
                fit_model4(log(HR.DFS), log(OR.PCR), DFS.SE, PCR.SE))
kable(all.dfs$summary)

## ----berpredefs, results = 'asis'----------------------------------------
params$CI <- sapply(1:nrow(params), function(i){
  
  with(params[i, ], fill_table(p1, p0, n, all.dfs)$a1)
  
})

params %>% 
  spread(n, CI) %>% kable

## ----allfig, echo = FALSE------------------------------------------------
baseEFS %+% rbind(trials10, trials13) + ggtitle("All 23 trials, EFS")

## ----cortos, results = 'asis'--------------------------------------------
ten.os <- with(trials10, fit_model4(log(HR.OS), log(OR.PCR), OS.SE, PCR.SE))
kable(ten.os$summary)

## ----cortpredos, results = 'asis'----------------------------------------
params$CI <- sapply(1:nrow(params), function(i){
  
  with(params[i, ], fill_table(p1, p0, n, ten.os)$a1)
  
})

params %>% 
  spread(n, CI) %>% kable

## ----cortfig2, echo = FALSE----------------------------------------------
xlim = c(0.38, 7.3)
ylim = c(0.08, 2.18)

baseOS <- ggplot(trials10, aes(x = OR.PCR, y = HR.OS, 
                 ymin = citr(HR.OS, OS.SE), ymax = citr(HR.OS, OS.SE, FALSE), 
                 xmin = citr(OR.PCR, PCR.SE), xmax = citr(OR.PCR, PCR.SE, FALSE), 
                 size = Patients)) + guides(size = FALSE) + 
  geom_point(shape = 15) + 
  scale_size_area(max_size = 3) + 
  geom_errorbar(width = 0.05, alpha = 1, size = .1, aes(size = NULL, color = NULL)) +
  geom_errorbarh(height = 0.05, alpha = 1, size = .1, aes(size = NULL, color = NULL)) +
  scale_y_continuous("Hazard ratio for OS", trans = "log", lim = ylim, breaks = c(.4, .6, .8, 1, 1.2, 1.4)) + 
  scale_x_continuous("Odds ratio for pCR", trans = "log", lim = xlim,  breaks = c(.1, 1, 2, 3, 5, 6)) + 
  geom_vline(xintercept = 1, size = .5, linetype = 3) + geom_hline(yintercept = 1, size = 0.5, linetype = 3) + 
  theme_bw() + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())

baseEFS + ggtitle("OS, 10 Trials")

## ----beros, results = 'asis'---------------------------------------------
all.os <- with(rbind(trials10, trials13), 
                fit_model4(log(HR.OS), log(OR.PCR), OS.SE, PCR.SE))
kable(all.os$summary)

## ----berpredos, results = 'asis'-----------------------------------------
params$CI <- sapply(1:nrow(params), function(i){
  
  with(params[i, ], fill_table(p1, p0, n, all.os)$a1)
  
})

params %>% 
  spread(n, CI) %>% kable

## ----allfig2, echo = FALSE-----------------------------------------------
baseOS %+% rbind(trials10, trials13) + ggtitle("All 23 trials, OS")

